This repository contains implementation for the AISTATS 2021 paper 
["Shapley Flow: A Graph-based Approach to Interpreting Model Predictions"](https://arxiv.org/pdf/2010.14592.pdf)

Tutorials can be found in the source repo located at https://github.com/nathanwang000/Shapley-Flow
